@@ -1,38 +1,24 @@
-#!/usr/bin/env python 
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013, NeXpy Development Team.
+# Copyright (c) 2013-2015, NeXpy Development Team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
 # The full license is in the file COPYING, distributed with this software.
 #-----------------------------------------------------------------------------
 
-""" A minimal application using the Qt console-style IPython frontend.
-
-This is not a complete console app, as subprocess will not be able to receive
-input, there is no real readline support, among other limitations.
-
-Based on IPython module of the same name.
-
-Authors:
-
-* Evan Patterson
-* Min RK
-* Erik Tollerud
-* Fernando Perez
-* Bussonnier Matthias
-* Thomas Kluyver
-* Paul Ivanov
-
+""" A minimal application using the Qt console-style Jupyter frontend.
 """
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+import six
 
-# stdlib imports
 import logging
 import logging.handlers
 import pkg_resources
@@ -41,69 +27,69 @@ import signal
 import sys
 import tempfile
 
-# System library imports
-from PySide import QtCore, QtGui
+from .pyqt import QtCore, QtGui
 
-# Local imports
-from mainwindow import MainWindow
-from treeview import NXtree
-from nexpy.api.nexus import nxclasses, nxload
+from .mainwindow import MainWindow
+from .treeview import NXtree
 
-# IPython imports
-from IPython.config.application import catch_config_error
-from IPython.core.application import BaseIPythonApplication
-from IPython.lib import guisupport
-from IPython.qt.console.ipython_widget import IPythonWidget
-from IPython.qt.console.rich_ipython_widget import RichIPythonWidget
-from IPython.qt.console import styles
-from IPython.utils.traitlets import (
+from nexusformat.nexus import nxclasses, nxload
+
+from traitlets.config.application import boolean_flag
+from traitlets.config.application import catch_config_error
+from qtconsole.jupyter_widget import JupyterWidget
+from qtconsole.rich_jupyter_widget import RichJupyterWidget
+from qtconsole import styles, __version__
+from qtconsole.client import QtKernelClient
+from qtconsole.manager import QtKernelManager
+from traitlets import (
     Dict, Unicode, CBool, Any
 )
 
-from IPython.consoleapp import (
-        IPythonConsoleApp, app_aliases, app_flags, flags, aliases
+from jupyter_core.application import JupyterApp, base_flags, base_aliases
+from jupyter_client.consoleapp import (
+        JupyterConsoleApp, app_aliases, app_flags,
     )
-
-#-----------------------------------------------------------------------------
-# Network Constants
-#-----------------------------------------------------------------------------
+from jupyter_client.localinterfaces import is_local_ip
 
 #-----------------------------------------------------------------------------
 # Globals
 #-----------------------------------------------------------------------------
 
-_examples = """
-ipython qtconsole                 # start the qtconsole
-ipython qtconsole --pylab=inline  # start with pylab in inline plotting mode
-"""
 _tree = None
 _shell = None
 _mainwindow = None
+_nexpy_dir = None
+_examples = """
+nexpy                      # start the GUI application
+"""
 
 #-----------------------------------------------------------------------------
 # Aliases and Flags
 #-----------------------------------------------------------------------------
 
-# start with copy of flags
-flags = dict(flags)
+flags = dict(base_flags)
 qt_flags = {
     'plain' : ({'NXConsoleApp' : {'plain' : True}},
             "Disable rich text support."),
 }
+qt_flags.update(boolean_flag(
+    'banner', 'NXConsoleApp.display_banner',
+    "Display a banner upon starting the QtConsole.",
+    "Don't display a banner upon starting the QtConsole."
+))
 
 # and app_flags from the Console Mixin
 qt_flags.update(app_flags)
 # add frontend flags to the full set
 flags.update(qt_flags)
 
-# start with copy of front&backend aliases list
-aliases = dict(aliases)
+# start with copy of base jupyter aliases
+aliases = dict(base_aliases)
 qt_aliases = dict(
-    style = 'IPythonWidget.syntax_style',
-    stylesheet = 'IPythonQtConsoleApp.stylesheet',
-    colors = 'ZMQInteractiveShell.colors',
+    style = 'JupyterWidget.syntax_style',
+    stylesheet = 'NXConsoleApp.stylesheet',
 
-    editor = 'IPythonWidget.editor',
+    editor = 'JupyterWidget.editor',
     paging = 'ConsoleWidget.paging',
 )
 # and app_aliases from the Console Mixin
@@ -114,56 +100,61 @@ aliases.update(qt_aliases)
 
 # get flags&aliases into sets, and remove a couple that
 # shouldn't be scrubbed from backend flags:
-qt_aliases = set(qt_aliases.keys())
-qt_aliases.remove('colors')
-qt_flags = set(qt_flags.keys())
-
-#-----------------------------------------------------------------------------
-# Classes
-#-----------------------------------------------------------------------------
+qt_aliases = set(qt_aliases)
+qt_flags = set(qt_flags)
 
 #-----------------------------------------------------------------------------
 # NXConsoleApp
 #-----------------------------------------------------------------------------
 
-class NXConsoleApp(BaseIPythonApplication, IPythonConsoleApp):
-    name = 'ipython-qtconsole'
-
+class NXConsoleApp(JupyterApp, JupyterConsoleApp):
+    name = 'nexpy-console'
+    version = __version__
     description = """
         The NeXpy Console.
-        
-        This launches a Console-style application using Qt. 
-        
+
+        This launches a Console-style application using Qt.
+
         The console is embedded in a GUI that contains a tree view of
         all NXroot groups and a matplotlib plotting pane. It also has all
-        the added benefits of an IPython Qt Console with multiline editing,
-        autocompletion, tooltips, command line histories and the ability to 
+        the added benefits of a Jupyter Qt Console with multiline editing,
+        autocompletion, tooltips, command line histories and the ability to
         save your session as HTML or print the output.
-        
-    """
 
-    classes = [IPythonWidget] + IPythonConsoleApp.classes
+    """
+    examples = _examples
+
+    classes = [JupyterWidget] + JupyterConsoleApp.classes
     flags = Dict(flags)
     aliases = Dict(aliases)
     frontend_flags = Any(qt_flags)
     frontend_aliases = Any(qt_aliases)
+    kernel_client_class = QtKernelClient
+    kernel_manager_class = QtKernelManager
 
     stylesheet = Unicode('', config=True,
         help="path to a custom CSS stylesheet")
 
+    hide_menubar = CBool(False, config=True,
+        help="Start the console window with the menu bar hidden.")
+
     plain = CBool(False, config=True,
         help="Use a plaintext widget instead of rich text (plain can't print/save).")
 
+    display_banner = CBool(True, config=True,
+        help="Whether to display a banner upon starting the QtConsole."
+    )
+
     def _plain_changed(self, name, old, new):
         kind = 'plain' if new else 'rich'
         self.config.ConsoleWidget.kind = kind
         if new:
-            self.widget_factory = IPythonWidget
+            self.widget_factory = JupyterWidget
         else:
-            self.widget_factory = RichIPythonWidget
+            self.widget_factory = RichJupyterWidget
 
     # the factory for creating a widget
-    widget_factory = Any(RichIPythonWidget)
+    widget_factory = Any(RichJupyterWidget)
 
     def parse_command_line(self, argv=None):
         super(NXConsoleApp, self).parse_command_line(argv)
@@ -187,55 +178,78 @@ class NXConsoleApp(BaseIPythonApplication, IPythonConsoleApp):
         _nexpy_dir = nexpy_dir
 
     def init_log(self):
-        log_file = os.path.join(_nexpy_dir, 'nexpy.log')
-        hdlr = logging.handlers.RotatingFileHandler(log_file, maxBytes=50000, 
-                                                    backupCount=5)
-        fmt = logging.Formatter(
-            "%(asctime)s - %(name)s - %(levelname)s - %(message)s", None)
-        hdlr.setFormatter(fmt)
+        value = os.getenv("NEXPY_LOG")
+        if value == None:
+            log_file = os.path.join(_nexpy_dir, 'nexpy.log')
+            hdlr = logging.handlers.RotatingFileHandler(log_file, maxBytes=50000,
+                                                        backupCount=5)
+            fmt = '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
+            fmtr = logging.Formatter(fmt, None)
+            logging.root.setLevel(logging.INFO)
+        else:
+            hdlr = logging.StreamHandler(stream=sys.stdout)
+            fmt = '%(levelname)s %(module)s.%(funcName)s() %(message)s'
+            fmtr = logging.Formatter(fmt)
+            try:
+                logging.root.setLevel(logging.__dict__[value])
+            except KeyError:
+                print('Invalid log level:', value)
+                sys.exit(1)
+        hdlr.setFormatter(fmtr)
         logging.root.addHandler(hdlr)
-        logging.root.setLevel(logging.INFO)
         logging.info('NeXpy launched')
+        logging.debug('Log level is: ' + str(value))
 
     def init_tree(self):
         """Initialize the NeXus tree used in the tree view."""
         global _tree
         self.tree = NXtree()
         _tree = self.tree
-        
+
     def init_gui(self):
         """Initialize the GUI."""
-        self.app = guisupport.get_app_qt4()
+        self.app = QtGui.QApplication.instance()
+        if self.app is None:
+            self.app = QtGui.QApplication(['nexpy'])
+        self.app.setApplicationName('nexpy')
         self.window = MainWindow(self.app, self.tree, config=self.config)
         self.window.log = self.log
         global _mainwindow
         _mainwindow = self.window
-        self.app.icon = QtGui.QIcon(
-            pkg_resources.resource_filename('nexpy.gui', 
-                                            'resources/icon/NeXpy.svg'))
-        QtGui.QApplication.setWindowIcon(self.app.icon)
+        try:
+            if 'svg' in QtGui.QImageReader.supportedImageFormats():
+                self.app.icon = QtGui.QIcon(
+                    pkg_resources.resource_filename('nexpy.gui',
+                                                    'resources/icon/NeXpy.svg'))
+            else:
+                self.app.icon = QtGui.QIcon(
+                    pkg_resources.resource_filename('nexpy.gui',
+                                                    'resources/icon/NeXpy.png'))
+            QtGui.QApplication.setWindowIcon(self.app.icon)
+        except Exception:
+            pass
 
-    def init_shell(self):
+    def init_shell(self, filename):
         """Initialize imports in the shell."""
         global _shell
         _shell = self.window.user_ns
-        s = ("import nexpy\n"
-             "import nexpy.api.nexus as nx\n"
-             "from nexpy.api.nexus import NXgroup, NXfield, NXattr, NXlink\n"
-             "from nexpy.api.nexus import NXFile\n"
+        s = ("import nexusformat.nexus as nx\n"
+             "from nexusformat.nexus import NXgroup, NXfield, NXattr, NXlink\n"
+             "from nexusformat.nexus import *\n"
+             "import nexpy\n"
              "from nexpy.gui.plotview import NXPlotView")
-        exec s in self.window.user_ns
-        
+        six.exec_(s, self.window.user_ns)
+
         s = ""
         for _class in nxclasses:
             s = "%s=nx.%s\n" % (_class,_class) + s
-        exec s in self.window.user_ns
+        six.exec_(s, self.window.user_ns)
 
         try:
-            f = open(os.path.join(os.path.expanduser('~'), '.nexpy', 
+            f = open(os.path.join(os.path.expanduser('~'), '.nexpy',
                                   'config.py'))
             s = ''.join(f.readlines())
-            exec s in self.window.user_ns
+            six.exec_(s, self.window.user_ns)
         except:
             s = ("import sys\n"
                  "import os\n"
@@ -246,18 +260,19 @@ class NXConsoleApp(BaseIPythonApplication, IPythonConsoleApp):
                  "import matplotlib as mpl\n"
                  "from matplotlib import pylab, mlab, pyplot\n"
                  "plt = pyplot")
-            exec s in self.window.user_ns
-        try:
-            print sys.argv[1]
-            fname = os.path.expanduser(sys.argv[1])
-            name = _mainwindow.treeview.tree.get_name(fname)
-            _mainwindow.treeview.tree[name] = self.window.user_ns[name] = nxload(fname)
-            _mainwindow.treeview.select_node(_mainwindow.treeview.tree[name])
-            logging.info("NeXus file '%s' opened as workspace '%s'" 
-                          % (fname, name))
-            self.window.user_ns[name].plot()
-        except:
-            pass
+            six.exec_(s,  self.window.user_ns)
+        if filename is not None:
+            try:
+                fname = os.path.expanduser(filename)
+                name = _mainwindow.treeview.tree.get_name(fname)
+                _mainwindow.treeview.tree[name] = self.window.user_ns[name] \
+                                                = nxload(fname)
+                _mainwindow.treeview.select_node(_mainwindow.treeview.tree[name])
+                logging.info("NeXus file '%s' opened as workspace '%s'"
+                              % (fname, name))
+                self.window.user_ns[name].plot()
+            except Exception:
+                pass
 
     def init_colors(self):
         """Configure the coloring of the widget"""
@@ -281,33 +296,33 @@ class NXConsoleApp(BaseIPythonApplication, IPythonConsoleApp):
         self._sigint_timer = timer
 
     @catch_config_error
-    def initialize(self, argv=None):
+    def initialize(self, filename=None, argv=None):
         super(NXConsoleApp, self).initialize(argv)
         self.init_dir()
         self.init_log()
         self.init_tree()
         self.init_gui()
-        self.init_shell()
+        self.init_shell(filename)
         self.init_colors()
         self.init_signal()
 
     def start(self):
+        super(NXConsoleApp, self).start()
 
         # draw the window
         self.window.show()
         self.window.raise_()
 
         # Start the application main loop.
-        guisupport.start_event_loop_qt4(self.app)
-#       self.app.exec_()
+        self.app.exec_()
 
 #-----------------------------------------------------------------------------
 # Main entry point
 #-----------------------------------------------------------------------------
 
-def main():
+def main(filename=None):
     app = NXConsoleApp()
-    app.initialize()
+    app.initialize(filename=filename)
     app.start()
 
 
