@@ -8,11 +8,15 @@
 #
 # The full license is in the file COPYING, distributed with this software.
 #-----------------------------------------------------------------------------
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+import six
+
 import os
 import pkg_resources
 
-from PySide import QtCore, QtGui
-from nexpy.api.nexus import NXfield, NXgroup, NXlink, NXroot, NXentry, NeXusError
+from .pyqt import QtCore, QtGui
+from nexusformat.nexus import *
 
 
 def natural_sort(key):
@@ -34,11 +38,11 @@ class NXtree(NXgroup):
 
     def __setitem__(self, key, value):
         if isinstance(value, NXroot):
-            if key not in self._entries.keys():
+            if key not in self._entries:
                 value._group = self
                 value._name = key
                 self._entries[key] = value
-                from nexpy.gui.consoleapp import _shell
+                from .consoleapp import _shell
                 _shell[key] = self._entries[key]
                 self.set_changed()
             else:
@@ -48,7 +52,7 @@ class NXtree(NXgroup):
     
     def __delitem__(self, key):
         del self._entries[key]
-        from nexpy.gui.consoleapp import _shell
+        from .consoleapp import _shell
         del _shell[key]
         self.set_changed()
 
@@ -91,25 +95,38 @@ class NXtree(NXgroup):
                 group = NXroot(node)
                 name = self.get_new_name()
                 self[name] = group
-                print "NeXpy: '%s' added to tree in '%s'" % (node.nxname, 
-                                                             group.nxname)
+                print("NeXpy: '%s' added to tree in '%s'" % (node.nxname,
+                                                             group.nxname))
             else:
                 group = NXroot(NXentry(node))
                 name = self.get_new_name()
                 self[name] = group
-                print "NeXpy: '%s' added to tree in '%s%s'" % (node.nxname, 
-                                              group.nxname, node.nxgroup.nxpath)
+                print("NeXpy: '%s' added to tree in '%s%s'" % (node.nxname,
+                                              group.nxname, node.nxgroup.nxpath))
         else:
             raise NeXusError("Only an NXgroup can be added to the tree")
 
+    def load(self, filename, mode='r'):
+        name = self.get_name(filename)
+        self[name] = nxload(filename, mode)
+
+    def reload(self, name):
+        if name in self:
+            root = nxload(self[name].nxfilename, self[name].nxfilemode)
+            if isinstance(root, NXroot):
+                del self[name]
+                self[name] = root
+        else:
+            raise NeXusError('%s not in the tree')
+
     def get_name(self, filename):
-        from nexpy.gui.consoleapp import _shell
+        from .consoleapp import _shell
         name = os.path.splitext(os.path.basename(filename))[0].replace(' ','_')
         name = "".join([c for c in name.replace('-','_') 
                         if c.isalpha() or c.isdigit() or c=='_'])
-        if name in _shell.keys():
+        if name in _shell:
             ind = []
-            for key in _shell.keys():
+            for key in _shell:
                 try:
                     if key.startswith(name+'_'): 
                         ind.append(int(key[len(name)+1:]))
@@ -120,9 +137,9 @@ class NXtree(NXgroup):
         return name
 
     def get_new_name(self):
-        from nexpy.gui.consoleapp import _shell
+        from .consoleapp import _shell
         ind = []
-        for key in _shell.keys():
+        for key in _shell:
             try:
                 if key.startswith('w'): 
                     ind.append(int(key[1:]))
@@ -132,12 +149,12 @@ class NXtree(NXgroup):
         return 'w'+str(sorted(ind)[-1]+1)
 
     def get_shell_names(self, node):
-        from nexpy.gui.consoleapp import _shell
+        from .consoleapp import _shell
         return [obj[0] for obj in _shell.items() if id(obj[1]) == id(node) 
                 and not obj[0].startswith('_')]
 
     def sync_shell_names(self):
-        from nexpy.gui.consoleapp import _shell
+        from .consoleapp import _shell
         for key, value in self.items():
             shell_names = self.get_shell_names(value)
             if key not in shell_names:
@@ -146,7 +163,7 @@ class NXtree(NXgroup):
                     del _shell[shell_names[0]]
 
     def node_from_file(self, fname):
-        return [name for name in self.keys() if 
+        return [name for name in self if 
             os.path.abspath(fname)==os.path.abspath(self[name].nxfilename)][0]
 
 
@@ -183,7 +200,7 @@ class NXTreeItem(QtGui.QStandardItem):
             return self.node.nxname
         elif role == QtCore.Qt.ToolTipRole:
             if self.node.tree.count('\n') > 50:
-                return '\n'.join(self.node.tree.split('\n')[0:50])+'\n...'
+                return '\n'.join(self.node.short_tree.split('\n')[0:50])+'\n...'
             else:
                 return self.node.tree
         elif role == QtCore.Qt.DecorationRole:
@@ -263,6 +280,8 @@ class NXTreeView(QtGui.QTreeView):
                                            triggered=self.overplot_data)
         self.overplot_line_action=QtGui.QAction("Overplot Line", self, 
                                            triggered=self.overplot_line)
+        self.plot_image_action=QtGui.QAction("Plot RGB(A) Image", self, 
+                                           triggered=self.plot_image)
         self.add_action=QtGui.QAction("Add...", self, triggered=self.add_data)
         self.initialize_action=QtGui.QAction("Initialize...", self, triggered=self.initialize_data)
         self.rename_action=QtGui.QAction("Rename...", self, triggered=self.rename_data)
@@ -275,28 +294,36 @@ class NXTreeView(QtGui.QTreeView):
         self.fit_action=QtGui.QAction("Fit...", self, triggered=self.fit_data)
         self.savefile_action=QtGui.QAction("Save as...", self, triggered=self.save_file)
         self.duplicate_action=QtGui.QAction("Duplicate...", self, triggered=self.duplicate)
+        self.reload_action=QtGui.QAction("Reload...", self, triggered=self.reload)
         self.remove_action=QtGui.QAction("Remove...", self, triggered=self.remove)
         self.lockfile_action=QtGui.QAction("Lock", self, triggered=self.lock_file)
         self.unlockfile_action=QtGui.QAction("Unlock...", self, triggered=self.unlock_file)
 
     def popMenu(self, node):
         menu = QtGui.QMenu(self)
-        menu.addAction(self.plot_data_action)
         try:
-            if ((isinstance(node, NXgroup) and node.nxsignal and node.nxsignal.ndim == 1) or
-                (isinstance(node, NXfield) and node.ndim == 1)):
-                menu.addAction(self.plot_line_action)
-                menu.addAction(self.overplot_data_action)
-                menu.addAction(self.overplot_line_action)
-        except NeXusError:
+            if node.is_plottable():
+                menu.addAction(self.plot_data_action)
+                if ((isinstance(node, NXgroup) and
+                    node.nxsignal and node.nxsignal.plot_rank == 1) or
+                    (isinstance(node, NXfield) and node.plot_rank == 1)):
+                    menu.addAction(self.plot_line_action)
+                    if self.mainwindow.plotview.ndim == 1:
+                        menu.addAction(self.overplot_data_action)
+                        menu.addAction(self.overplot_line_action)
+                if ((isinstance(node, NXgroup) and node.plottable_data and
+                     node.plottable_data.nxsignal and
+                     node.plottable_data.nxsignal.plot_rank > 2) or
+                    (isinstance(node, NXfield) and node.plot_rank > 2)):
+                    menu.addAction(self.plot_image_action)
+                menu.addSeparator()
+        except Exception:
             pass
-        menu.addSeparator()
         menu.addAction(self.add_action)
         if not isinstance(node, NXroot):
             if isinstance(node, NXgroup):
                 menu.addAction(self.initialize_action)
-        if not isinstance(node, NXlink):
-            menu.addAction(self.rename_action)
+        menu.addAction(self.rename_action)
         if isinstance(node, NXroot) and not node.nxfilemode:
             menu.addAction(self.delete_action)
         elif not isinstance(node, NXroot):
@@ -325,7 +352,10 @@ class NXTreeView(QtGui.QTreeView):
                 menu.addAction(self.unlockfile_action)
             else:
                 menu.addAction(self.lockfile_action)
+            menu.addSeparator()
             menu.addAction(self.remove_action)
+        if node.nxfilemode:
+            menu.addAction(self.reload_action)
         return menu
 
     def save_file(self):
@@ -334,6 +364,9 @@ class NXTreeView(QtGui.QTreeView):
     def duplicate(self):
         self.mainwindow.duplicate()
 
+    def reload(self):
+        self.mainwindow.reload()
+
     def remove(self):
         self.mainwindow.remove()
 
@@ -347,13 +380,16 @@ class NXTreeView(QtGui.QTreeView):
         self.mainwindow.plot_data()
 
     def plot_line(self):
-        self.mainwindow.plot_data('-')
+        self.mainwindow.plot_line()
 
     def overplot_data(self):
         self.mainwindow.overplot_data()
 
     def overplot_line(self):
-        self.mainwindow.overplot_data('-')
+        self.mainwindow.overplot_line()
+
+    def plot_image(self):
+        self.mainwindow.plot_image()
 
     def add_data(self):
         self.mainwindow.add_data()
@@ -417,6 +453,8 @@ class NXTreeView(QtGui.QTreeView):
         idx = self.get_index(node)
         if idx:
             self.setCurrentIndex(idx)
+        self.selectionModel().select(self.currentIndex(),
+                                     QtGui.QItemSelectionModel.Select)
         
     def selectionChanged(self, new, old):
         if new.indexes():
