@@ -1,4 +1,4 @@
-#!/usr/bin/env python 
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 #-----------------------------------------------------------------------------
@@ -8,20 +8,22 @@
 #
 # The full license is in the file COPYING, distributed with this software.
 #-----------------------------------------------------------------------------
-
+from __future__ import print_function
 
 def main():
 
-    # MUST define the QT_API before importing matplotlib
-    import os, sys
-    os.environ['QT_API'] = 'pyside'
-    
-    import matplotlib
-    matplotlib.use('Qt4Agg')
+    import argparse, nexpy, os, sys
 
+    parser = argparse.ArgumentParser(description="Launch NeXpy")
+
+    parser.add_argument('filename', nargs='?', 
+                        help='NeXus file to open on launch (optional)')
+    parser.add_argument('-v', '--version', action='version', 
+                        version='%(prog)s v'+nexpy.__version__)
+    args = parser.parse_args()
     sys.path.insert(0, os.path.abspath(os.path.join('..')))
     from nexpy.gui.consoleapp import main
-    main()
+    main(args.filename)
 
 
 if __name__ == '__main__':
