@@ -1,4 +1,4 @@
-#!/usr/bin/env python 
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 #-----------------------------------------------------------------------------
@@ -11,36 +11,30 @@
 
 """
 Module to read in data from a Globus Online catalog and convert it to NeXus.
-
-Each importer needs to layout the GUI buttons necessary for defining the imported file 
-and its attributes and a single module, get_data, which returns an NXroot or NXentry
-object. This will be added to the NeXpy tree.
-
-Two GUI elements are provided for convenience:
-
-    ImportDialog.filebox: Contains a "Choose File" button and a text box. Both can be 
-                          used to set the path to the imported file. This can be 
-                          retrieved as a string using self.get_filename().
-    ImportDialog.buttonbox: Contains a "Cancel" and "OK" button to close the dialog. 
-                            This should be placed at the bottom of all import dialogs.
 """
-import os                           #@UnusedImport
 
-from IPython.external.qt import QtGui
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 
-from nexpy.api.nexus import *       #@UnusedWildImport
+import os
+
+from nexpy.gui.pyqt import QtCore, QtGui
+
+import numpy as np
+from globusonline.catalog.client.examples.catalog_wrapper import CatalogWrapper
+
+from nexusformat.nexus import *
 from nexpy.gui.importdialog import BaseImportDialog
 
 filetype = "Catalog File"
 
 class ImportDialog(BaseImportDialog):
     """Dialog to import data from a Globus Online catalog"""
- 
+
     def __init__(self, parent=None):
 
         super(ImportDialog, self).__init__(parent)
-        
-        from globusonline.catalog.client.examples.catalog_wrapper import CatalogWrapper
+
         token_file = os.path.join(os.path.expanduser('~'),'.nexpy',
                                   'globusonline', 'gotoken.txt')
         self.wrap = CatalogWrapper(token='file', token_file=token_file)
@@ -59,9 +53,9 @@ class ImportDialog(BaseImportDialog):
         catalog_layout.addWidget(catalog_button)
         self.layout = QtGui.QVBoxLayout()
         self.layout.addLayout(catalog_layout)
-        self.layout.addWidget(self.buttonbox())
+        self.layout.addWidget(self.close_buttons())
         self.setLayout(self.layout)
-  
+
         self.setWindowTitle("Import "+str(filetype))
 
     def get_catalog(self):
@@ -79,13 +73,13 @@ class ImportDialog(BaseImportDialog):
         dataset_button.clicked.connect(self.get_dataset)
         dataset_layout.addWidget(self.dataset_box)
         dataset_layout.addWidget(dataset_button)
-        self.layout.insertLayout(1, dataset_layout)            
+        self.layout.insertLayout(1, dataset_layout)
 
     def get_catalog_id(self, name):
         for catalog in self.catalogs:
             if catalog['config']['name']==name:
                 return catalog['id']
- 
+
     def get_dataset(self):
         self.dataset_id = self.get_dataset_id(self.dataset_box.currentText())
         _,self.members = self.wrap.catalogClient.get_members(self.catalog_id,
@@ -101,8 +95,8 @@ class ImportDialog(BaseImportDialog):
         member_button = QtGui.QPushButton("Choose Member")
         member_button.clicked.connect(self.get_member)
         member_layout.addWidget(self.member_box)
-        member_layout.addWidget(member_button)            
-        self.layout.insertLayout(2, member_layout)            
+        member_layout.addWidget(member_button)
+        self.layout.insertLayout(2, member_layout)
 
     def get_dataset_id(self, name):
         for dataset in self.datasets:
@@ -110,9 +104,9 @@ class ImportDialog(BaseImportDialog):
                 return dataset['id']
 
     def get_member(self):
-        print self.catalog_id, self.dataset_id
-        self.wrap.transfer_members(self.catalog_id, self.dataset_id, 
+        print(self.catalog_id, self.dataset_id)
+        self.wrap.transfer_members(self.catalog_id, self.dataset_id,
             '/Users/rosborn/Desktop')
- 
+
     def get_data(self):
         return NXentry()
