@@ -11,26 +11,17 @@
 
 """
 Module to read in a SPE or NXSPE file and convert it to NeXus.
-
-Each importer needs to layout the GUI buttons necessary for defining the imported file 
-and its attributes and a single module, get_data, which returns an NXroot or NXentry
-object. This will be added to the NeXpy tree.
-
-Two GUI elements are provided for convenience:
-
-    ImportDialog.filebox: Contains a "Choose File" button and a text box. Both can be 
-                          used to set the path to the imported file. This can be 
-                          retrieved as a string using self.get_filename().
-    ImportDialog.buttonbox: Contains a "Cancel" and "OK" button to close the dialog. 
-                            This should be placed at the bottom of all import dialogs.
 """
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 
-import os                           #@UnusedImport
-from IPython.external.qt import QtGui
+import os
+import numpy as np
 
-import numpy as np                  #@UnusedImport
-from nexpy.api.nexus import *       #@UnusedWildImport
-from nexpy.api.nexus.tree import convert_index, centers
+from nexpy.gui.pyqt import QtGui
+
+from nexusformat.nexus import *
+from nexusformat.nexus.tree import convert_index, centers
 from nexpy.gui.importdialog import BaseImportDialog
 
 filetype = "SPE/NXSPE File"
@@ -81,7 +72,7 @@ class ImportDialog(BaseImportDialog):
         step_layout.addStretch()
         layout.addLayout(step_layout)
 
-        layout.addWidget(self.buttonbox())
+        layout.addWidget(self.close_buttons())
 
         self.setLayout(layout)
   
@@ -92,8 +83,7 @@ class ImportDialog(BaseImportDialog):
         Opens a file dialog and sets the file text box to the chosen path.
         """
         dirname = self.get_default_directory(self.filename.text())
-        filename, _ = QtGui.QFileDialog.getOpenFileName(self, 'Open File',
-            dirname)
+        filename = getOpenFileName(self, 'Open File', dirname)
         if os.path.exists(filename):    # avoids problems if <Cancel> was selected
             dirname = os.path.dirname(filename)
             self.filename.setText(str(filename))
@@ -285,7 +275,7 @@ def readspe(spefile):
     f = open(spefile, 'r')
     lines = f.readlines()
     f.close()
-    nphi, nomega = map(int, lines[0].split())
+    nphi, nomega = list(map(int, lines[0].split()))
     i = 2
     phi = readaxisblock(lines, i, nphi+1)
     i = i + ((phi.size-1)/8) + 2
@@ -324,9 +314,9 @@ def readspeblock(lines, start, size):
 		values = np.zeros(size)
 		offset = 0
 		for line in lines[start:start+nlines]:
-			buffer = filter(lambda x: x.strip(), 
-							[line[i:i+10] for i in range(0,80,10)])
-			values[offset:offset+len(buffer)] = map(float, buffer)
+			buffer = list(filter(lambda x: x.strip(), 
+						  [line[i:i+10] for i in range(0,80,10)]))
+			values[offset:offset+len(buffer)] = [float(x) for x in buffer]
 			offset = offset + len(buffer)
 		return values.clip(0.0,1e8)    
 
