@@ -8,14 +8,18 @@
 #
 # The full license is in the file COPYING, distributed with this software.
 #-----------------------------------------------------------------------------
+"""
+Module to read in a SPEC file and convert it to NeXus.
+"""
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 
-'''Module to read in a SPEC file and convert it to NeXus.'''
+import os
+import numpy as np
 
-from PySide import QtCore, QtGui    #@UnusedImport
+from nexpy.gui.pyqt import QtCore, QtGui, getOpenFileName
 
-import numpy as np                  #@UnusedImport
-import os                           #@UnusedImport
-from nexpy.api.nexus import *       #@UnusedWildImport
+from nexusformat.nexus import *
 from nexpy.gui.importdialog import BaseImportDialog
 
 filetype = "SPEC File"
@@ -28,20 +32,25 @@ class ImportDialog(BaseImportDialog):
 
         super(ImportDialog, self).__init__(parent)
 
+        try:
+            import spec2nexus
+        except ImportError:
+            raise NeXusError("Please install the 'spec2nexus' module")
+
         self.accepted = False
         from nexpy.gui.consoleapp import _mainwindow
         self.default_directory = _mainwindow.default_directory
         self.import_file = None     # must set in self.get_data()
         self.spec = None
 
-        # TODO: how is this updated?
+        # progress bar is updated via calls to pdate_progress()
         self.progress_bar = QtGui.QProgressBar()
         self.progress_bar.setVisible(False)
 
         status_layout = QtGui.QHBoxLayout()
         status_layout.addWidget(self.progress_bar)
         status_layout.addStretch()
-        status_layout.addWidget(self.buttonbox())
+        status_layout.addWidget(self.close_buttons())
 
         self.layout = QtGui.QVBoxLayout()
         self.layout.addLayout(self.filebox())
@@ -69,21 +78,24 @@ class ImportDialog(BaseImportDialog):
         scanbox.addWidget(self.scanmax)
         return scanbox
 
+    def get_scan_numbers(self):
+        return sorted([int(s) for s in self.spec.getScanNumbers()])
+
     def choose_file(self):
         '''
         Opens file dialog, set file text box to the chosen path
         '''
-        from spec2nexus.prjPySpec import SpecDataFile
-
+        from spec2nexus.spec import SpecDataFile
         dirname = self.get_default_directory(self.filename.text())
-        filename, _ = QtGui.QFileDialog.getOpenFileName(self, 'Open file', dirname)
+        filename = getOpenFileName(self, 'Open file', dirname)
         if os.path.exists(filename):
             self.filename.setText(str(filename))
             self.spec = SpecDataFile(self.get_filename())
             self.set_default_directory(os.path.dirname(filename))
-            scan_min = self.spec.getMinScanNumber()
+            all_scans = self.get_scan_numbers()
+            scan_min = all_scans[0]
             self.scanmin.setText(str(scan_min))
-            scan_max = self.spec.getMaxScanNumber()
+            scan_max = all_scans[-1]
             self.scanmax.setText(str(scan_max))
 
     def get_data(self):
@@ -95,7 +107,7 @@ class ImportDialog(BaseImportDialog):
             return None
         scan_min = int(self.scanmin.text())
         scan_max = int(self.scanmax.text())
-        all_scans = self.spec.getScanNumbers()
+        all_scans = self.get_scan_numbers()
         scans = [s for s in all_scans if scan_min <= s <= scan_max]
         self.spec.progress_bar = self.progress_bar
         self.spec.update_progress = self.update_progress
@@ -139,15 +151,15 @@ class Parser(object):
         if self.SPECfile is None:
             return None
 
-        complete_scan_list = self.SPECfile.scans.keys()
-        for key in scan_list:
+        complete_scan_list = list(self.SPECfile.scans)
+        for key in [str(s) for s in scan_list]:
             if key not in complete_scan_list:
                 msg = 'scan ' + str(key) + ' was not found'
-                raise ValueError, msg
-        
+                raise ValueError(msg)
+
         root = NXroot()
 
-        root.attrs['prjPySpec_version'] = spec2nexus.__version__
+        root.attrs['spec2nexus'] = str(spec2nexus.__version__)
         header0 = self.SPECfile.headers[0]
         root.attrs['SPEC_file'] = self.SPECfile.fileName
         root.attrs['SPEC_epoch'] = header0.epoch
@@ -163,8 +175,9 @@ class Parser(object):
 
         self.progress_bar.setVisible(True)
         self.progress_bar.setRange(scan_list[0], scan_list[-1])
-        for key in scan_list:
+        for key in [str(s) for s in scan_list]:
             scan = self.SPECfile.getScan(key)
+            scan.interpret()
             entry = NXentry()
             entry.title = str(scan)
             entry.date = utils.iso8601(scan.date)  
@@ -174,7 +187,7 @@ class Parser(object):
             entry.data = self.scan_NXdata(scan)            # store the scan data
             entry.positioners = self.metadata_NXlog(scan.positioner, 
                                                     'SPEC positioners (#P & #O lines)')
-            if len(scan.metadata) > 0:
+            if hasattr(scan, 'metadata') and len(scan.metadata) > 0:
                 entry.metadata = self.metadata_NXlog(scan.metadata, 
                                                      'SPEC metadata (UNICAT-style #H & #V lines)')
 
@@ -185,7 +198,7 @@ class Parser(object):
                 # http://certif.com/spec_manual/fourc_4_9.html
                 entry.G.attrs['description'] = desc
                 for item, value in scan.G.items():
-                    entry.G[item] = NXfield(map(float, value.split()))
+                    entry.G[item] = NXfield(list(map(float, value.split())))
             if scan.T != '':
                 entry['counting_basis'] = NXfield('SPEC scan with constant counting time')
                 entry['T'] = NXfield(float(scan.T))
@@ -197,12 +210,12 @@ class Parser(object):
                 entry['M'].units = 'counts'
                 entry['M'].description = 'SPEC scan with constant monitor count'
             if scan.Q != '':
-                entry['Q'] = NXfield(map(float,scan.Q.split()))
+                entry['Q'] = NXfield(list(map(float,scan.Q)))
                 entry['Q'].description = 'hkl at start of scan'
 
             root['scan_' + str(key)] = entry
 
-            self.progress_bar.setValue(key)
+            self.progress_bar.setValue(int(key))
             self.update_progress()
 
         return root
@@ -212,6 +225,17 @@ class Parser(object):
         return the scan data in an NXdata object
         '''
         nxdata = NXdata()
+
+        if len(scan.data) == 0:       # what if no data?
+            # since no data available, provide trivial, fake data
+            # this keeps the NXdata base class compliant with the NeXus standard
+            nxdata.attrs['description'] = 'SPEC scan has no data'
+            nxdata['noSpecData_y'] = NXfield([0, 0])   # primary Y axis
+            nxdata['noSpecData_x'] = NXfield([0, 0])   # primary X axis
+            nxdata.nxsignal = nxdata['noSpecData_y']
+            nxdata.nxaxes   = [nxdata['noSpecData_x'], ]
+            return nxdata
+
         nxdata.attrs['description'] = 'SPEC scan data'
         
         scan_type = scan.scanCmd.split()[0]
@@ -233,16 +257,16 @@ class Parser(object):
         # these locations suggested to NIAC, easier to parse than attached to dataset!
         nxdata.attrs['signal'] = nxdata.nxsignal.nxname         
         nxdata.attrs['axes'] = ':'.join([obj.nxname for obj in nxdata.nxaxes])
-        
         return nxdata
     
     def parser_1D_columns(self, nxdata, scan):
         '''generic data parser for 1-D column data'''
         from spec2nexus import utils
         for column in scan.L:
-            clean_name = utils.sanitize_name(nxdata, column)
-            nxdata[clean_name] = NXfield(scan.data[column])
-            nxdata[clean_name].original_name = column
+            if column in scan.data:
+                clean_name = utils.sanitize_name(nxdata, column)
+                nxdata[clean_name] = NXfield(scan.data[column])
+                nxdata[clean_name].original_name = column
 
         signal = utils.sanitize_name(nxdata, scan.column_last)      # primary Y axis
         axis = utils.sanitize_name(nxdata, scan.column_first)       # primary X axis
@@ -263,11 +287,11 @@ class Parser(object):
     def parser_mesh(self, nxdata, scan):
         '''data parser for 2-D mesh and hklmesh'''
         # 2-D parser: http://www.certif.com/spec_help/mesh.html
-        # mesh motor1 start1 end1 intervals1 motor2 start2 end2 intervals2 time
+        #  mesh motor1 start1 end1 intervals1 motor2 start2 end2 intervals2 time
         # 2-D parser: http://www.certif.com/spec_help/hklmesh.html
         #  hklmesh Q1 start1 end1 intervals1 Q2 start2 end2 intervals2 time
-        # mesh:    nexpy/examples/33id_spec.dat  scan 22
-        # hklmesh: nexpy/examples/33bm_spec.dat  scan 17
+        # mesh:    nexpy/examples/33id_spec.dat  scan 22  (also has MCA, thus 3-D data)
+        # hklmesh: nexpy/examples/33bm_spec.dat  scan 17  (no MCA data)
         from spec2nexus import utils
         label1, start1, end1, intervals1, label2, start2, end2, intervals2, time = scan.scanCmd.split()[1:]
         if label1 not in scan.data:
@@ -276,10 +300,13 @@ class Parser(object):
             label2 = scan.L[1]      # mnemonic v. name
         axis1 = scan.data.get(label1)
         axis2 = scan.data.get(label2)
-        intervals1, intervals2 = map(int, (intervals1, intervals2))
-        start1, end1, start2, end2, time = map(float, (start1, end1, start2, end2, time))
+        intervals1, intervals2 = int(intervals1), int(intervals2)
+        start1, end1 = float(start1), float(end1)
+        start2, end2 = float(start2), float(end2)
+        time = float(time)
         if len(axis1) < intervals1:     # stopped scan before second row started
             self.parser_1D_columns(nxdata, scan)        # fallback support
+            # TODO: what about the MCA data in this case?
         else:
             axis1 = axis1[0:intervals1+1]
             axis2 = [axis2[row] for row in range(len(axis2)) if row % (intervals1+1) == 0]
@@ -311,11 +338,26 @@ class Parser(object):
 
         if '_mca_' in scan.data:    # 3-D array
             # TODO: ?merge with parser_mca_spectra()?
-            num_channels = len(scan.data['_mca_'][0])
-            data_shape.append(num_channels)
+            _num_spectra = len(scan.data['_mca_'])
+            spectra_lengths = list(map(len, scan.data['_mca_']))
+            num_channels = max(spectra_lengths)
+            if num_channels != min(spectra_lengths):
+                msg = 'MCA spectra have different lengths'
+                msg += ' in scan #' + str(scan.scanNum)
+                msg += ' in file ' + str(scan.specFile)
+                raise ValueError(msg)
+            data_shape += [num_channels, ]
             mca = np.array(scan.data['_mca_'])
             nxdata.mca__spectrum_ = NXfield(utils.reshape_data(mca, data_shape))
-            nxdata.mca__spectrum_channel = NXfield(range(1, num_channels+1))
+            try:
+                # use MCA channel numbers as known at time of scan
+                chan1 = scan.MCA['first_saved']
+                chanN = scan.MCA['last_saved']
+                channel_range = range(chan1, chanN+1)
+            except:
+                # basic indices
+                channel_range = range(1, num_channels+1)
+            nxdata.mca__spectrum_channel = NXfield(channel_range)
             nxdata.mca__spectrum_channel.units = 'channel'
             axes = (label1, label2, 'mca__spectrum_channel')
             nxdata.mca__spectrum_.axes = ':'.join( axes )
