@@ -11,24 +11,16 @@
 
 """
 Module to read in a folder of image files and convert them to NeXus.
-
-Each importer needs to layout the GUI buttons necessary for defining the imported file 
-and its attributes and a single module, get_data, which returns an NXroot or NXentry
-object. This will be added to the NeXpy tree.
-
-Two GUI elements are provided for convenience:
-
-    ImportDialog.filebox: Contains a "Choose File" button and a text box. Both can be 
-                          used to set the path to the imported file. This can be 
-                          retrieved as a string using self.get_filename().
-    ImportDialog.buttonbox: Contains a "Cancel" and "OK" button to close the dialog. 
-                            This should be placed at the bottom of all import dialogs.
 """
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 
-from IPython.external.qt import QtGui, QtCore
-import os, re
+import os
+import re
 import numpy as np
-from nexpy.api.nexus import NXfield, NXentry, NXdata
+
+from nexusformat.nexus import NXfield, NXentry, NXdata, NeXusError
+from nexpy.gui.pyqt import QtGui, QtCore
 from nexpy.gui.importdialog import BaseImportDialog
 
 filetype = "Image Stack"
@@ -253,20 +245,14 @@ class ImportDialog(BaseImportDialog):
             imsize = cbf.get_image_size(0)
             return np.fromstring(cbf.get_integerarray_as_string(),np.int32).reshape(imsize)
         else:
-            from nexpy.readers.tifffile import tifffile as TIFF
-            return TIFF.imread(filename)
+            import tifffile
+            return tifffile.imread(filename)
 
     def read_images(self, filenames):
-        if self.get_image_type() == 'CBF':
-            v0 = self.read_image(filenames[0])
-            v = np.zeros([len(filenames), v0.shape[0], v0.shape[1]], dtype=np.int32)
-            i = 0
-            for filename in filenames:
-                v[i] = self.read_image(filename)
-                i += 1
-        else:
-            from nexpy.readers.tifffile import tifffile as TIFF
-            v = TIFF.TiffSequence(filenames).asarray()        
+        v0 = self.read_image(filenames[0])
+        v = np.zeros([len(filenames), v0.shape[0], v0.shape[1]], dtype=np.int32)
+        for i,filename in enumerate(filenames):
+            v[i] = self.read_image(filename)
         global maximum
         if v.max() > maximum:
             maximum = v.max()
@@ -279,6 +265,16 @@ class ImportDialog(BaseImportDialog):
         else:
             self.import_file = self.get_directory()       
         filenames = self.get_files()
+        if self.get_image_type() == 'CBF':
+            try:
+                import pycbf
+            except ImportError:
+                raise NeXusError("Please install the 'pycbf' module")
+        else:
+            try:
+                import tifffile
+            except ImportError:
+                raise NeXusError("Please install the 'tifffile' module")
         v0 = self.read_image(filenames[0])
         x = NXfield(range(v0.shape[1]), dtype=np.uint16, name='x')
         y = NXfield(range(v0.shape[0]), dtype=np.uint16, name='y')
@@ -292,7 +288,7 @@ class ImportDialog(BaseImportDialog):
             chunk_size = v.shape[0]/10
         self.progress_bar.setVisible(True)
         self.progress_bar.setRange(0, len(filenames))
-        for i in range(0, len(filenames)):
+        for i in range(0, len(filenames), chunk_size):
             try:
                 files = []
                 for j in range(i,i+chunk_size):
