@@ -11,14 +11,14 @@
 #-----------------------------------------------------------------------------
 
 pkg_requirements = [
+    'nexusformat>=0.2.1',
     'numpy>=1.6.0',
     'scipy',
     'h5py',
-    'PySide>=1.1.0',
-    'ipython>=1.1.0',
-    'matplotlib',
+    'jupyter',
+    'ipython>=4.0.0',
+    'matplotlib>=1.4.0',
 ]
 extra_requirements = {
-    'spec': ['spec2nexus>=2014.0320.6',],
+    'spec': ['spec2nexus>=2014.1228.0',],
 }
-
